/*
 * GkSu -- Gtk+ Frontend to su
 * Copyright (C) 2002 Gustavo Noronha Silva
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>

#include <gtk/gtk.h>

#include "defines.h"

#include "gksu.h"
#include "util.h"
#include "xauth.h"

void
clean_dir (const gchar *dirname)
{
  gchar *xauthname;
  
  xauthname = g_strdup_printf ("%s/.Xauthority", dirname);
  if (!unlink (xauthname))
    rmdir (dirname);
}

int
prepare_xauth (GkConf *conf)
{
  FILE *xauth_output;
  char xauth[256] = {0};

  /* xauth stuff, borrowed from gnome-sudo */
  conf->dir = mkdtemp (conf->dir_template);
  if (!conf->dir)
    {
      gk_dialog(GTK_MESSAGE_ERROR, strerror(errno));
      exit (1);
    }

  /* directory must not be 700 */
  chmod (conf->dir, S_IRUSR|S_IWUSR|S_IXUSR|S_IROTH|S_IWOTH|S_IXOTH);

  /* get the authorization token */
  xauth_output = popen ("xauth list $DISPLAY | cut -d ' ' -f 5", "r");
  fread (xauth, sizeof(char), 255, xauth_output);
  pclose (xauth_output);

  conf->xauth_file = g_strdup_printf ("%s/.Xauthority", conf->dir);
  conf->xauth = g_strdup (xauth);
  conf->display = getenv ("DISPLAY");

  return 0;
}

